#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportEtcApplyorderSignModel(object):

    def __init__(self):
        self._agent_appid = None
        self._agent_pid = None
        self._alipay_order_id = None
        self._open_id = None
        self._out_order_id = None
        self._seller_id = None
        self._sign_return_url = None
        self._user_id = None
        self._vehicle_info_sync_flag = None

    @property
    def agent_appid(self):
        return self._agent_appid

    @agent_appid.setter
    def agent_appid(self, value):
        self._agent_appid = value
    @property
    def agent_pid(self):
        return self._agent_pid

    @agent_pid.setter
    def agent_pid(self, value):
        self._agent_pid = value
    @property
    def alipay_order_id(self):
        return self._alipay_order_id

    @alipay_order_id.setter
    def alipay_order_id(self, value):
        self._alipay_order_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def sign_return_url(self):
        return self._sign_return_url

    @sign_return_url.setter
    def sign_return_url(self, value):
        self._sign_return_url = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def vehicle_info_sync_flag(self):
        return self._vehicle_info_sync_flag

    @vehicle_info_sync_flag.setter
    def vehicle_info_sync_flag(self, value):
        self._vehicle_info_sync_flag = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_appid:
            if hasattr(self.agent_appid, 'to_alipay_dict'):
                params['agent_appid'] = self.agent_appid.to_alipay_dict()
            else:
                params['agent_appid'] = self.agent_appid
        if self.agent_pid:
            if hasattr(self.agent_pid, 'to_alipay_dict'):
                params['agent_pid'] = self.agent_pid.to_alipay_dict()
            else:
                params['agent_pid'] = self.agent_pid
        if self.alipay_order_id:
            if hasattr(self.alipay_order_id, 'to_alipay_dict'):
                params['alipay_order_id'] = self.alipay_order_id.to_alipay_dict()
            else:
                params['alipay_order_id'] = self.alipay_order_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.sign_return_url:
            if hasattr(self.sign_return_url, 'to_alipay_dict'):
                params['sign_return_url'] = self.sign_return_url.to_alipay_dict()
            else:
                params['sign_return_url'] = self.sign_return_url
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.vehicle_info_sync_flag:
            if hasattr(self.vehicle_info_sync_flag, 'to_alipay_dict'):
                params['vehicle_info_sync_flag'] = self.vehicle_info_sync_flag.to_alipay_dict()
            else:
                params['vehicle_info_sync_flag'] = self.vehicle_info_sync_flag
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportEtcApplyorderSignModel()
        if 'agent_appid' in d:
            o.agent_appid = d['agent_appid']
        if 'agent_pid' in d:
            o.agent_pid = d['agent_pid']
        if 'alipay_order_id' in d:
            o.alipay_order_id = d['alipay_order_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'sign_return_url' in d:
            o.sign_return_url = d['sign_return_url']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'vehicle_info_sync_flag' in d:
            o.vehicle_info_sync_flag = d['vehicle_info_sync_flag']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class NearMallBo(object):

    def __init__(self):
        self._attribute = None
        self._distance = None
        self._latitude = None
        self._longitude = None
        self._mall_id = None
        self._mall_logo = None
        self._mall_name = None

    @property
    def attribute(self):
        return self._attribute

    @attribute.setter
    def attribute(self, value):
        self._attribute = value
    @property
    def distance(self):
        return self._distance

    @distance.setter
    def distance(self, value):
        self._distance = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def mall_id(self):
        return self._mall_id

    @mall_id.setter
    def mall_id(self, value):
        self._mall_id = value
    @property
    def mall_logo(self):
        return self._mall_logo

    @mall_logo.setter
    def mall_logo(self, value):
        self._mall_logo = value
    @property
    def mall_name(self):
        return self._mall_name

    @mall_name.setter
    def mall_name(self, value):
        self._mall_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.attribute:
            if hasattr(self.attribute, 'to_alipay_dict'):
                params['attribute'] = self.attribute.to_alipay_dict()
            else:
                params['attribute'] = self.attribute
        if self.distance:
            if hasattr(self.distance, 'to_alipay_dict'):
                params['distance'] = self.distance.to_alipay_dict()
            else:
                params['distance'] = self.distance
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.mall_id:
            if hasattr(self.mall_id, 'to_alipay_dict'):
                params['mall_id'] = self.mall_id.to_alipay_dict()
            else:
                params['mall_id'] = self.mall_id
        if self.mall_logo:
            if hasattr(self.mall_logo, 'to_alipay_dict'):
                params['mall_logo'] = self.mall_logo.to_alipay_dict()
            else:
                params['mall_logo'] = self.mall_logo
        if self.mall_name:
            if hasattr(self.mall_name, 'to_alipay_dict'):
                params['mall_name'] = self.mall_name.to_alipay_dict()
            else:
                params['mall_name'] = self.mall_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = NearMallBo()
        if 'attribute' in d:
            o.attribute = d['attribute']
        if 'distance' in d:
            o.distance = d['distance']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'mall_id' in d:
            o.mall_id = d['mall_id']
        if 'mall_logo' in d:
            o.mall_logo = d['mall_logo']
        if 'mall_name' in d:
            o.mall_name = d['mall_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbdishGroupInfo import KbdishGroupInfo


class KoubeiCateringDishGroupSyncModel(object):

    def __init__(self):
        self._kb_dish_group = None
        self._syn_type = None

    @property
    def kb_dish_group(self):
        return self._kb_dish_group

    @kb_dish_group.setter
    def kb_dish_group(self, value):
        if isinstance(value, KbdishGroupInfo):
            self._kb_dish_group = value
        else:
            self._kb_dish_group = KbdishGroupInfo.from_alipay_dict(value)
    @property
    def syn_type(self):
        return self._syn_type

    @syn_type.setter
    def syn_type(self, value):
        self._syn_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.kb_dish_group:
            if hasattr(self.kb_dish_group, 'to_alipay_dict'):
                params['kb_dish_group'] = self.kb_dish_group.to_alipay_dict()
            else:
                params['kb_dish_group'] = self.kb_dish_group
        if self.syn_type:
            if hasattr(self.syn_type, 'to_alipay_dict'):
                params['syn_type'] = self.syn_type.to_alipay_dict()
            else:
                params['syn_type'] = self.syn_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishGroupSyncModel()
        if 'kb_dish_group' in d:
            o.kb_dish_group = d['kb_dish_group']
        if 'syn_type' in d:
            o.syn_type = d['syn_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JobworthAdapter import JobworthAdapter


class ZhimaCustomerJobworthAdapterQueryModel(object):

    def __init__(self):
        self._adapter = None
        self._cert_no = None
        self._cert_type = None
        self._job_name = None
        self._open_id = None
        self._user_id = None
        self._user_name = None

    @property
    def adapter(self):
        return self._adapter

    @adapter.setter
    def adapter(self, value):
        if isinstance(value, JobworthAdapter):
            self._adapter = value
        else:
            self._adapter = JobworthAdapter.from_alipay_dict(value)
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def cert_type(self):
        return self._cert_type

    @cert_type.setter
    def cert_type(self, value):
        self._cert_type = value
    @property
    def job_name(self):
        return self._job_name

    @job_name.setter
    def job_name(self, value):
        self._job_name = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.adapter:
            if hasattr(self.adapter, 'to_alipay_dict'):
                params['adapter'] = self.adapter.to_alipay_dict()
            else:
                params['adapter'] = self.adapter
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.cert_type:
            if hasattr(self.cert_type, 'to_alipay_dict'):
                params['cert_type'] = self.cert_type.to_alipay_dict()
            else:
                params['cert_type'] = self.cert_type
        if self.job_name:
            if hasattr(self.job_name, 'to_alipay_dict'):
                params['job_name'] = self.job_name.to_alipay_dict()
            else:
                params['job_name'] = self.job_name
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCustomerJobworthAdapterQueryModel()
        if 'adapter' in d:
            o.adapter = d['adapter']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'cert_type' in d:
            o.cert_type = d['cert_type']
        if 'job_name' in d:
            o.job_name = d['job_name']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_name' in d:
            o.user_name = d['user_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SourceOffer(object):

    def __init__(self):
        self._offer_id = None
        self._offer_type = None

    @property
    def offer_id(self):
        return self._offer_id

    @offer_id.setter
    def offer_id(self, value):
        self._offer_id = value
    @property
    def offer_type(self):
        return self._offer_type

    @offer_type.setter
    def offer_type(self, value):
        self._offer_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.offer_id:
            if hasattr(self.offer_id, 'to_alipay_dict'):
                params['offer_id'] = self.offer_id.to_alipay_dict()
            else:
                params['offer_id'] = self.offer_id
        if self.offer_type:
            if hasattr(self.offer_type, 'to_alipay_dict'):
                params['offer_type'] = self.offer_type.to_alipay_dict()
            else:
                params['offer_type'] = self.offer_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SourceOffer()
        if 'offer_id' in d:
            o.offer_id = d['offer_id']
        if 'offer_type' in d:
            o.offer_type = d['offer_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TradeApplyParams import TradeApplyParams


class AlipayCommerceTradeApplyModel(object):

    def __init__(self):
        self._amount_detail = None
        self._channel = None
        self._interface_version = None
        self._op_code = None
        self._open_id = None
        self._order_detail = None
        self._scene_code = None
        self._target_id = None
        self._target_id_type = None
        self._trade_apply_params = None

    @property
    def amount_detail(self):
        return self._amount_detail

    @amount_detail.setter
    def amount_detail(self, value):
        self._amount_detail = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def interface_version(self):
        return self._interface_version

    @interface_version.setter
    def interface_version(self, value):
        self._interface_version = value
    @property
    def op_code(self):
        return self._op_code

    @op_code.setter
    def op_code(self, value):
        self._op_code = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_detail(self):
        return self._order_detail

    @order_detail.setter
    def order_detail(self, value):
        self._order_detail = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_id_type(self):
        return self._target_id_type

    @target_id_type.setter
    def target_id_type(self, value):
        self._target_id_type = value
    @property
    def trade_apply_params(self):
        return self._trade_apply_params

    @trade_apply_params.setter
    def trade_apply_params(self, value):
        if isinstance(value, TradeApplyParams):
            self._trade_apply_params = value
        else:
            self._trade_apply_params = TradeApplyParams.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.amount_detail:
            if hasattr(self.amount_detail, 'to_alipay_dict'):
                params['amount_detail'] = self.amount_detail.to_alipay_dict()
            else:
                params['amount_detail'] = self.amount_detail
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.interface_version:
            if hasattr(self.interface_version, 'to_alipay_dict'):
                params['interface_version'] = self.interface_version.to_alipay_dict()
            else:
                params['interface_version'] = self.interface_version
        if self.op_code:
            if hasattr(self.op_code, 'to_alipay_dict'):
                params['op_code'] = self.op_code.to_alipay_dict()
            else:
                params['op_code'] = self.op_code
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_detail:
            if hasattr(self.order_detail, 'to_alipay_dict'):
                params['order_detail'] = self.order_detail.to_alipay_dict()
            else:
                params['order_detail'] = self.order_detail
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_id_type:
            if hasattr(self.target_id_type, 'to_alipay_dict'):
                params['target_id_type'] = self.target_id_type.to_alipay_dict()
            else:
                params['target_id_type'] = self.target_id_type
        if self.trade_apply_params:
            if hasattr(self.trade_apply_params, 'to_alipay_dict'):
                params['trade_apply_params'] = self.trade_apply_params.to_alipay_dict()
            else:
                params['trade_apply_params'] = self.trade_apply_params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTradeApplyModel()
        if 'amount_detail' in d:
            o.amount_detail = d['amount_detail']
        if 'channel' in d:
            o.channel = d['channel']
        if 'interface_version' in d:
            o.interface_version = d['interface_version']
        if 'op_code' in d:
            o.op_code = d['op_code']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_detail' in d:
            o.order_detail = d['order_detail']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_id_type' in d:
            o.target_id_type = d['target_id_type']
        if 'trade_apply_params' in d:
            o.trade_apply_params = d['trade_apply_params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityProdXwbtestabcAbcQueryModel(object):

    def __init__(self):
        self._xwb = None

    @property
    def xwb(self):
        return self._xwb

    @xwb.setter
    def xwb(self, value):
        self._xwb = value


    def to_alipay_dict(self):
        params = dict()
        if self.xwb:
            if hasattr(self.xwb, 'to_alipay_dict'):
                params['xwb'] = self.xwb.to_alipay_dict()
            else:
                params['xwb'] = self.xwb
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdXwbtestabcAbcQueryModel()
        if 'xwb' in d:
            o.xwb = d['xwb']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniBaseinfoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniBaseinfoQueryResponse, self).__init__()
        self._app_desc = None
        self._app_english_name = None
        self._app_logo = None
        self._app_name = None
        self._app_slogan = None
        self._category_names = None
        self._package_names = None
        self._safe_domains = None
        self._service_email = None
        self._service_phone = None

    @property
    def app_desc(self):
        return self._app_desc

    @app_desc.setter
    def app_desc(self, value):
        self._app_desc = value
    @property
    def app_english_name(self):
        return self._app_english_name

    @app_english_name.setter
    def app_english_name(self, value):
        self._app_english_name = value
    @property
    def app_logo(self):
        return self._app_logo

    @app_logo.setter
    def app_logo(self, value):
        self._app_logo = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_slogan(self):
        return self._app_slogan

    @app_slogan.setter
    def app_slogan(self, value):
        self._app_slogan = value
    @property
    def category_names(self):
        return self._category_names

    @category_names.setter
    def category_names(self, value):
        self._category_names = value
    @property
    def package_names(self):
        return self._package_names

    @package_names.setter
    def package_names(self, value):
        if isinstance(value, list):
            self._package_names = list()
            for i in value:
                self._package_names.append(i)
    @property
    def safe_domains(self):
        return self._safe_domains

    @safe_domains.setter
    def safe_domains(self, value):
        if isinstance(value, list):
            self._safe_domains = list()
            for i in value:
                self._safe_domains.append(i)
    @property
    def service_email(self):
        return self._service_email

    @service_email.setter
    def service_email(self, value):
        self._service_email = value
    @property
    def service_phone(self):
        return self._service_phone

    @service_phone.setter
    def service_phone(self, value):
        self._service_phone = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniBaseinfoQueryResponse, self).parse_response_content(response_content)
        if 'app_desc' in response:
            self.app_desc = response['app_desc']
        if 'app_english_name' in response:
            self.app_english_name = response['app_english_name']
        if 'app_logo' in response:
            self.app_logo = response['app_logo']
        if 'app_name' in response:
            self.app_name = response['app_name']
        if 'app_slogan' in response:
            self.app_slogan = response['app_slogan']
        if 'category_names' in response:
            self.category_names = response['category_names']
        if 'package_names' in response:
            self.package_names = response['package_names']
        if 'safe_domains' in response:
            self.safe_domains = response['safe_domains']
        if 'service_email' in response:
            self.service_email = response['service_email']
        if 'service_phone' in response:
            self.service_phone = response['service_phone']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingCampaignRetailDmModifyModel(object):

    def __init__(self):
        self._action_url = None
        self._activity_end_time = None
        self._activity_start_time = None
        self._brief = None
        self._campaign_end_time = None
        self._campaign_type = None
        self._content_id = None
        self._coupon_type = None
        self._description = None
        self._ext_info = None
        self._image_id = None
        self._item_brand = None
        self._item_category = None
        self._item_code = None
        self._item_name = None
        self._member_only = None
        self._shop_ids = None
        self._thumbnail_image_id = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def activity_end_time(self):
        return self._activity_end_time

    @activity_end_time.setter
    def activity_end_time(self, value):
        self._activity_end_time = value
    @property
    def activity_start_time(self):
        return self._activity_start_time

    @activity_start_time.setter
    def activity_start_time(self, value):
        self._activity_start_time = value
    @property
    def brief(self):
        return self._brief

    @brief.setter
    def brief(self, value):
        self._brief = value
    @property
    def campaign_end_time(self):
        return self._campaign_end_time

    @campaign_end_time.setter
    def campaign_end_time(self, value):
        self._campaign_end_time = value
    @property
    def campaign_type(self):
        return self._campaign_type

    @campaign_type.setter
    def campaign_type(self, value):
        self._campaign_type = value
    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def coupon_type(self):
        return self._coupon_type

    @coupon_type.setter
    def coupon_type(self, value):
        self._coupon_type = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def image_id(self):
        return self._image_id

    @image_id.setter
    def image_id(self, value):
        self._image_id = value
    @property
    def item_brand(self):
        return self._item_brand

    @item_brand.setter
    def item_brand(self, value):
        self._item_brand = value
    @property
    def item_category(self):
        return self._item_category

    @item_category.setter
    def item_category(self, value):
        self._item_category = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def member_only(self):
        return self._member_only

    @member_only.setter
    def member_only(self, value):
        self._member_only = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def thumbnail_image_id(self):
        return self._thumbnail_image_id

    @thumbnail_image_id.setter
    def thumbnail_image_id(self, value):
        self._thumbnail_image_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.activity_end_time:
            if hasattr(self.activity_end_time, 'to_alipay_dict'):
                params['activity_end_time'] = self.activity_end_time.to_alipay_dict()
            else:
                params['activity_end_time'] = self.activity_end_time
        if self.activity_start_time:
            if hasattr(self.activity_start_time, 'to_alipay_dict'):
                params['activity_start_time'] = self.activity_start_time.to_alipay_dict()
            else:
                params['activity_start_time'] = self.activity_start_time
        if self.brief:
            if hasattr(self.brief, 'to_alipay_dict'):
                params['brief'] = self.brief.to_alipay_dict()
            else:
                params['brief'] = self.brief
        if self.campaign_end_time:
            if hasattr(self.campaign_end_time, 'to_alipay_dict'):
                params['campaign_end_time'] = self.campaign_end_time.to_alipay_dict()
            else:
                params['campaign_end_time'] = self.campaign_end_time
        if self.campaign_type:
            if hasattr(self.campaign_type, 'to_alipay_dict'):
                params['campaign_type'] = self.campaign_type.to_alipay_dict()
            else:
                params['campaign_type'] = self.campaign_type
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.coupon_type:
            if hasattr(self.coupon_type, 'to_alipay_dict'):
                params['coupon_type'] = self.coupon_type.to_alipay_dict()
            else:
                params['coupon_type'] = self.coupon_type
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.image_id:
            if hasattr(self.image_id, 'to_alipay_dict'):
                params['image_id'] = self.image_id.to_alipay_dict()
            else:
                params['image_id'] = self.image_id
        if self.item_brand:
            if hasattr(self.item_brand, 'to_alipay_dict'):
                params['item_brand'] = self.item_brand.to_alipay_dict()
            else:
                params['item_brand'] = self.item_brand
        if self.item_category:
            if hasattr(self.item_category, 'to_alipay_dict'):
                params['item_category'] = self.item_category.to_alipay_dict()
            else:
                params['item_category'] = self.item_category
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.member_only:
            if hasattr(self.member_only, 'to_alipay_dict'):
                params['member_only'] = self.member_only.to_alipay_dict()
            else:
                params['member_only'] = self.member_only
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.thumbnail_image_id:
            if hasattr(self.thumbnail_image_id, 'to_alipay_dict'):
                params['thumbnail_image_id'] = self.thumbnail_image_id.to_alipay_dict()
            else:
                params['thumbnail_image_id'] = self.thumbnail_image_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignRetailDmModifyModel()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'activity_end_time' in d:
            o.activity_end_time = d['activity_end_time']
        if 'activity_start_time' in d:
            o.activity_start_time = d['activity_start_time']
        if 'brief' in d:
            o.brief = d['brief']
        if 'campaign_end_time' in d:
            o.campaign_end_time = d['campaign_end_time']
        if 'campaign_type' in d:
            o.campaign_type = d['campaign_type']
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'coupon_type' in d:
            o.coupon_type = d['coupon_type']
        if 'description' in d:
            o.description = d['description']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'image_id' in d:
            o.image_id = d['image_id']
        if 'item_brand' in d:
            o.item_brand = d['item_brand']
        if 'item_category' in d:
            o.item_category = d['item_category']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'member_only' in d:
            o.member_only = d['member_only']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'thumbnail_image_id' in d:
            o.thumbnail_image_id = d['thumbnail_image_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class RefundGoodsDetail(object):

    def __init__(self):
        self._goods_id = None
        self._refund_amount = None

    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.refund_amount:
            if hasattr(self.refund_amount, 'to_alipay_dict'):
                params['refund_amount'] = self.refund_amount.to_alipay_dict()
            else:
                params['refund_amount'] = self.refund_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = RefundGoodsDetail()
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'refund_amount' in d:
            o.refund_amount = d['refund_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CfbudmacApplyBizBudgetRequest import CfbudmacApplyBizBudgetRequest


class MyxiaojinFinanceBudgetApplyModel(object):

    def __init__(self):
        self._apply_biz_budget_request_list = None
        self._idempotent_id = None

    @property
    def apply_biz_budget_request_list(self):
        return self._apply_biz_budget_request_list

    @apply_biz_budget_request_list.setter
    def apply_biz_budget_request_list(self, value):
        if isinstance(value, list):
            self._apply_biz_budget_request_list = list()
            for i in value:
                if isinstance(i, CfbudmacApplyBizBudgetRequest):
                    self._apply_biz_budget_request_list.append(i)
                else:
                    self._apply_biz_budget_request_list.append(CfbudmacApplyBizBudgetRequest.from_alipay_dict(i))
    @property
    def idempotent_id(self):
        return self._idempotent_id

    @idempotent_id.setter
    def idempotent_id(self, value):
        self._idempotent_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_biz_budget_request_list:
            if isinstance(self.apply_biz_budget_request_list, list):
                for i in range(0, len(self.apply_biz_budget_request_list)):
                    element = self.apply_biz_budget_request_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.apply_biz_budget_request_list[i] = element.to_alipay_dict()
            if hasattr(self.apply_biz_budget_request_list, 'to_alipay_dict'):
                params['apply_biz_budget_request_list'] = self.apply_biz_budget_request_list.to_alipay_dict()
            else:
                params['apply_biz_budget_request_list'] = self.apply_biz_budget_request_list
        if self.idempotent_id:
            if hasattr(self.idempotent_id, 'to_alipay_dict'):
                params['idempotent_id'] = self.idempotent_id.to_alipay_dict()
            else:
                params['idempotent_id'] = self.idempotent_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MyxiaojinFinanceBudgetApplyModel()
        if 'apply_biz_budget_request_list' in d:
            o.apply_biz_budget_request_list = d['apply_biz_budget_request_list']
        if 'idempotent_id' in d:
            o.idempotent_id = d['idempotent_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDigitalmgmtEcmcoreDataarchivesCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDigitalmgmtEcmcoreDataarchivesCreateResponse, self).__init__()
        self._data_id = None
        self._message_content = None
        self._status = None

    @property
    def data_id(self):
        return self._data_id

    @data_id.setter
    def data_id(self, value):
        self._data_id = value
    @property
    def message_content(self):
        return self._message_content

    @message_content.setter
    def message_content(self, value):
        self._message_content = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayDigitalmgmtEcmcoreDataarchivesCreateResponse, self).parse_response_content(response_content)
        if 'data_id' in response:
            self.data_id = response['data_id']
        if 'message_content' in response:
            self.message_content = response['message_content']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PromoterDeleteInfo import PromoterDeleteInfo


class AlipayCommerceOperationPromoterRelationDeleteResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationPromoterRelationDeleteResponse, self).__init__()
        self._promoter_delete_result = None

    @property
    def promoter_delete_result(self):
        return self._promoter_delete_result

    @promoter_delete_result.setter
    def promoter_delete_result(self, value):
        if isinstance(value, PromoterDeleteInfo):
            self._promoter_delete_result = value
        else:
            self._promoter_delete_result = PromoterDeleteInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationPromoterRelationDeleteResponse, self).parse_response_content(response_content)
        if 'promoter_delete_result' in response:
            self.promoter_delete_result = response['promoter_delete_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BankCardInfo(object):

    def __init__(self):
        self._bank_branch_name = None
        self._card_name = None
        self._card_no = None

    @property
    def bank_branch_name(self):
        return self._bank_branch_name

    @bank_branch_name.setter
    def bank_branch_name(self, value):
        self._bank_branch_name = value
    @property
    def card_name(self):
        return self._card_name

    @card_name.setter
    def card_name(self, value):
        self._card_name = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_branch_name:
            if hasattr(self.bank_branch_name, 'to_alipay_dict'):
                params['bank_branch_name'] = self.bank_branch_name.to_alipay_dict()
            else:
                params['bank_branch_name'] = self.bank_branch_name
        if self.card_name:
            if hasattr(self.card_name, 'to_alipay_dict'):
                params['card_name'] = self.card_name.to_alipay_dict()
            else:
                params['card_name'] = self.card_name
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BankCardInfo()
        if 'bank_branch_name' in d:
            o.bank_branch_name = d['bank_branch_name']
        if 'card_name' in d:
            o.card_name = d['card_name']
        if 'card_no' in d:
            o.card_no = d['card_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppIndustryGovHealthcodeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppIndustryGovHealthcodeQueryResponse, self).__init__()
        self._code_color = None
        self._code_content = None
        self._refresh_time = None
        self._user_name = None

    @property
    def code_color(self):
        return self._code_color

    @code_color.setter
    def code_color(self, value):
        self._code_color = value
    @property
    def code_content(self):
        return self._code_content

    @code_content.setter
    def code_content(self, value):
        self._code_content = value
    @property
    def refresh_time(self):
        return self._refresh_time

    @refresh_time.setter
    def refresh_time(self, value):
        self._refresh_time = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppIndustryGovHealthcodeQueryResponse, self).parse_response_content(response_content)
        if 'code_color' in response:
            self.code_color = response['code_color']
        if 'code_content' in response:
            self.code_content = response['code_content']
        if 'refresh_time' in response:
            self.refresh_time = response['refresh_time']
        if 'user_name' in response:
            self.user_name = response['user_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFincoreComplianceSignListApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFincoreComplianceSignListApplyResponse, self).__init__()
        self._business_id = None
        self._file_code = None

    @property
    def business_id(self):
        return self._business_id

    @business_id.setter
    def business_id(self, value):
        self._business_id = value
    @property
    def file_code(self):
        return self._file_code

    @file_code.setter
    def file_code(self, value):
        self._file_code = value

    def parse_response_content(self, response_content):
        response = super(AlipayFincoreComplianceSignListApplyResponse, self).parse_response_content(response_content)
        if 'business_id' in response:
            self.business_id = response['business_id']
        if 'file_code' in response:
            self.file_code = response['file_code']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GreenEnergyLogsDTO(object):

    def __init__(self):
        self._energy_amount = None
        self._energy_desc = None
        self._energy_tags = None
        self._goods_name = None
        self._log_id = None
        self._record_time = None
        self._result_code = None
        self._result_message = None
        self._status = None

    @property
    def energy_amount(self):
        return self._energy_amount

    @energy_amount.setter
    def energy_amount(self, value):
        self._energy_amount = value
    @property
    def energy_desc(self):
        return self._energy_desc

    @energy_desc.setter
    def energy_desc(self, value):
        self._energy_desc = value
    @property
    def energy_tags(self):
        return self._energy_tags

    @energy_tags.setter
    def energy_tags(self, value):
        if isinstance(value, list):
            self._energy_tags = list()
            for i in value:
                self._energy_tags.append(i)
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def log_id(self):
        return self._log_id

    @log_id.setter
    def log_id(self, value):
        self._log_id = value
    @property
    def record_time(self):
        return self._record_time

    @record_time.setter
    def record_time(self, value):
        self._record_time = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.energy_amount:
            if hasattr(self.energy_amount, 'to_alipay_dict'):
                params['energy_amount'] = self.energy_amount.to_alipay_dict()
            else:
                params['energy_amount'] = self.energy_amount
        if self.energy_desc:
            if hasattr(self.energy_desc, 'to_alipay_dict'):
                params['energy_desc'] = self.energy_desc.to_alipay_dict()
            else:
                params['energy_desc'] = self.energy_desc
        if self.energy_tags:
            if isinstance(self.energy_tags, list):
                for i in range(0, len(self.energy_tags)):
                    element = self.energy_tags[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.energy_tags[i] = element.to_alipay_dict()
            if hasattr(self.energy_tags, 'to_alipay_dict'):
                params['energy_tags'] = self.energy_tags.to_alipay_dict()
            else:
                params['energy_tags'] = self.energy_tags
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.log_id:
            if hasattr(self.log_id, 'to_alipay_dict'):
                params['log_id'] = self.log_id.to_alipay_dict()
            else:
                params['log_id'] = self.log_id
        if self.record_time:
            if hasattr(self.record_time, 'to_alipay_dict'):
                params['record_time'] = self.record_time.to_alipay_dict()
            else:
                params['record_time'] = self.record_time
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.result_message:
            if hasattr(self.result_message, 'to_alipay_dict'):
                params['result_message'] = self.result_message.to_alipay_dict()
            else:
                params['result_message'] = self.result_message
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GreenEnergyLogsDTO()
        if 'energy_amount' in d:
            o.energy_amount = d['energy_amount']
        if 'energy_desc' in d:
            o.energy_desc = d['energy_desc']
        if 'energy_tags' in d:
            o.energy_tags = d['energy_tags']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'log_id' in d:
            o.log_id = d['log_id']
        if 'record_time' in d:
            o.record_time = d['record_time']
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'result_message' in d:
            o.result_message = d['result_message']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AssetResult import AssetResult


class AntMerchantExpandAssetreverseAssignSyncModel(object):

    def __init__(self):
        self._reverse_results = None

    @property
    def reverse_results(self):
        return self._reverse_results

    @reverse_results.setter
    def reverse_results(self, value):
        if isinstance(value, list):
            self._reverse_results = list()
            for i in value:
                if isinstance(i, AssetResult):
                    self._reverse_results.append(i)
                else:
                    self._reverse_results.append(AssetResult.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.reverse_results:
            if isinstance(self.reverse_results, list):
                for i in range(0, len(self.reverse_results)):
                    element = self.reverse_results[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.reverse_results[i] = element.to_alipay_dict()
            if hasattr(self.reverse_results, 'to_alipay_dict'):
                params['reverse_results'] = self.reverse_results.to_alipay_dict()
            else:
                params['reverse_results'] = self.reverse_results
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandAssetreverseAssignSyncModel()
        if 'reverse_results' in d:
            o.reverse_results = d['reverse_results']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeRepaybillModifyModel(object):

    def __init__(self):
        self._amount = None
        self._bill_no = None
        self._bill_status = None
        self._operation_type = None
        self._out_request_no = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_status(self):
        return self._bill_status

    @bill_status.setter
    def bill_status(self, value):
        self._bill_status = value
    @property
    def operation_type(self):
        return self._operation_type

    @operation_type.setter
    def operation_type(self, value):
        self._operation_type = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.bill_status:
            if hasattr(self.bill_status, 'to_alipay_dict'):
                params['bill_status'] = self.bill_status.to_alipay_dict()
            else:
                params['bill_status'] = self.bill_status
        if self.operation_type:
            if hasattr(self.operation_type, 'to_alipay_dict'):
                params['operation_type'] = self.operation_type.to_alipay_dict()
            else:
                params['operation_type'] = self.operation_type
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeRepaybillModifyModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'bill_status' in d:
            o.bill_status = d['bill_status']
        if 'operation_type' in d:
            o.operation_type = d['operation_type']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotWifiStatusQueryModel(object):

    def __init__(self):
        self._biz_tid = None

    @property
    def biz_tid(self):
        return self._biz_tid

    @biz_tid.setter
    def biz_tid(self, value):
        self._biz_tid = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_tid:
            if hasattr(self.biz_tid, 'to_alipay_dict'):
                params['biz_tid'] = self.biz_tid.to_alipay_dict()
            else:
                params['biz_tid'] = self.biz_tid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotWifiStatusQueryModel()
        if 'biz_tid' in d:
            o.biz_tid = d['biz_tid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPayAppSmartwearManagementSyncModel(object):

    def __init__(self):
        self._command = None
        self._payload = None

    @property
    def command(self):
        return self._command

    @command.setter
    def command(self, value):
        self._command = value
    @property
    def payload(self):
        return self._payload

    @payload.setter
    def payload(self, value):
        self._payload = value


    def to_alipay_dict(self):
        params = dict()
        if self.command:
            if hasattr(self.command, 'to_alipay_dict'):
                params['command'] = self.command.to_alipay_dict()
            else:
                params['command'] = self.command
        if self.payload:
            if hasattr(self.payload, 'to_alipay_dict'):
                params['payload'] = self.payload.to_alipay_dict()
            else:
                params['payload'] = self.payload
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPayAppSmartwearManagementSyncModel()
        if 'command' in d:
            o.command = d['command']
        if 'payload' in d:
            o.payload = d['payload']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CrowdSelectTagOpenRequest import CrowdSelectTagOpenRequest


class AlipayMarketingQipanCrowdwithtagQueryModel(object):

    def __init__(self):
        self._crowd_id = None
        self._select_tag_list = None

    @property
    def crowd_id(self):
        return self._crowd_id

    @crowd_id.setter
    def crowd_id(self, value):
        self._crowd_id = value
    @property
    def select_tag_list(self):
        return self._select_tag_list

    @select_tag_list.setter
    def select_tag_list(self, value):
        if isinstance(value, list):
            self._select_tag_list = list()
            for i in value:
                if isinstance(i, CrowdSelectTagOpenRequest):
                    self._select_tag_list.append(i)
                else:
                    self._select_tag_list.append(CrowdSelectTagOpenRequest.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_id:
            if hasattr(self.crowd_id, 'to_alipay_dict'):
                params['crowd_id'] = self.crowd_id.to_alipay_dict()
            else:
                params['crowd_id'] = self.crowd_id
        if self.select_tag_list:
            if isinstance(self.select_tag_list, list):
                for i in range(0, len(self.select_tag_list)):
                    element = self.select_tag_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.select_tag_list[i] = element.to_alipay_dict()
            if hasattr(self.select_tag_list, 'to_alipay_dict'):
                params['select_tag_list'] = self.select_tag_list.to_alipay_dict()
            else:
                params['select_tag_list'] = self.select_tag_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingQipanCrowdwithtagQueryModel()
        if 'crowd_id' in d:
            o.crowd_id = d['crowd_id']
        if 'select_tag_list' in d:
            o.select_tag_list = d['select_tag_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SlmArtifactInfo(object):

    def __init__(self):
        self._name = None
        self._size = None
        self._uri = None

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def size(self):
        return self._size

    @size.setter
    def size(self, value):
        self._size = value
    @property
    def uri(self):
        return self._uri

    @uri.setter
    def uri(self, value):
        self._uri = value


    def to_alipay_dict(self):
        params = dict()
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.size:
            if hasattr(self.size, 'to_alipay_dict'):
                params['size'] = self.size.to_alipay_dict()
            else:
                params['size'] = self.size
        if self.uri:
            if hasattr(self.uri, 'to_alipay_dict'):
                params['uri'] = self.uri.to_alipay_dict()
            else:
                params['uri'] = self.uri
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SlmArtifactInfo()
        if 'name' in d:
            o.name = d['name']
        if 'size' in d:
            o.size = d['size']
        if 'uri' in d:
            o.uri = d['uri']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateSceneConfigQueryModel(object):

    def __init__(self):
        self._school_id = None
        self._school_std_code = None

    @property
    def school_id(self):
        return self._school_id

    @school_id.setter
    def school_id(self, value):
        self._school_id = value
    @property
    def school_std_code(self):
        return self._school_std_code

    @school_std_code.setter
    def school_std_code(self, value):
        self._school_std_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.school_id:
            if hasattr(self.school_id, 'to_alipay_dict'):
                params['school_id'] = self.school_id.to_alipay_dict()
            else:
                params['school_id'] = self.school_id
        if self.school_std_code:
            if hasattr(self.school_std_code, 'to_alipay_dict'):
                params['school_std_code'] = self.school_std_code.to_alipay_dict()
            else:
                params['school_std_code'] = self.school_std_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateSceneConfigQueryModel()
        if 'school_id' in d:
            o.school_id = d['school_id']
        if 'school_std_code' in d:
            o.school_std_code = d['school_std_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceKidsAccountCreateModel(object):

    def __init__(self):
        self._child_cert_no = None
        self._child_cert_type = None
        self._child_name = None
        self._class_name = None
        self._contact_mobile = None
        self._out_biz_id = None
        self._out_biz_type = None
        self._parent_open_id = None
        self._parent_uid = None
        self._scene_code = None
        self._school_id = None
        self._student_no = None

    @property
    def child_cert_no(self):
        return self._child_cert_no

    @child_cert_no.setter
    def child_cert_no(self, value):
        self._child_cert_no = value
    @property
    def child_cert_type(self):
        return self._child_cert_type

    @child_cert_type.setter
    def child_cert_type(self, value):
        self._child_cert_type = value
    @property
    def child_name(self):
        return self._child_name

    @child_name.setter
    def child_name(self, value):
        self._child_name = value
    @property
    def class_name(self):
        return self._class_name

    @class_name.setter
    def class_name(self, value):
        self._class_name = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def out_biz_id(self):
        return self._out_biz_id

    @out_biz_id.setter
    def out_biz_id(self, value):
        self._out_biz_id = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def parent_open_id(self):
        return self._parent_open_id

    @parent_open_id.setter
    def parent_open_id(self, value):
        self._parent_open_id = value
    @property
    def parent_uid(self):
        return self._parent_uid

    @parent_uid.setter
    def parent_uid(self, value):
        self._parent_uid = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def school_id(self):
        return self._school_id

    @school_id.setter
    def school_id(self, value):
        self._school_id = value
    @property
    def student_no(self):
        return self._student_no

    @student_no.setter
    def student_no(self, value):
        self._student_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.child_cert_no:
            if hasattr(self.child_cert_no, 'to_alipay_dict'):
                params['child_cert_no'] = self.child_cert_no.to_alipay_dict()
            else:
                params['child_cert_no'] = self.child_cert_no
        if self.child_cert_type:
            if hasattr(self.child_cert_type, 'to_alipay_dict'):
                params['child_cert_type'] = self.child_cert_type.to_alipay_dict()
            else:
                params['child_cert_type'] = self.child_cert_type
        if self.child_name:
            if hasattr(self.child_name, 'to_alipay_dict'):
                params['child_name'] = self.child_name.to_alipay_dict()
            else:
                params['child_name'] = self.child_name
        if self.class_name:
            if hasattr(self.class_name, 'to_alipay_dict'):
                params['class_name'] = self.class_name.to_alipay_dict()
            else:
                params['class_name'] = self.class_name
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.out_biz_id:
            if hasattr(self.out_biz_id, 'to_alipay_dict'):
                params['out_biz_id'] = self.out_biz_id.to_alipay_dict()
            else:
                params['out_biz_id'] = self.out_biz_id
        if self.out_biz_type:
            if hasattr(self.out_biz_type, 'to_alipay_dict'):
                params['out_biz_type'] = self.out_biz_type.to_alipay_dict()
            else:
                params['out_biz_type'] = self.out_biz_type
        if self.parent_open_id:
            if hasattr(self.parent_open_id, 'to_alipay_dict'):
                params['parent_open_id'] = self.parent_open_id.to_alipay_dict()
            else:
                params['parent_open_id'] = self.parent_open_id
        if self.parent_uid:
            if hasattr(self.parent_uid, 'to_alipay_dict'):
                params['parent_uid'] = self.parent_uid.to_alipay_dict()
            else:
                params['parent_uid'] = self.parent_uid
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.school_id:
            if hasattr(self.school_id, 'to_alipay_dict'):
                params['school_id'] = self.school_id.to_alipay_dict()
            else:
                params['school_id'] = self.school_id
        if self.student_no:
            if hasattr(self.student_no, 'to_alipay_dict'):
                params['student_no'] = self.student_no.to_alipay_dict()
            else:
                params['student_no'] = self.student_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceKidsAccountCreateModel()
        if 'child_cert_no' in d:
            o.child_cert_no = d['child_cert_no']
        if 'child_cert_type' in d:
            o.child_cert_type = d['child_cert_type']
        if 'child_name' in d:
            o.child_name = d['child_name']
        if 'class_name' in d:
            o.class_name = d['class_name']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'out_biz_id' in d:
            o.out_biz_id = d['out_biz_id']
        if 'out_biz_type' in d:
            o.out_biz_type = d['out_biz_type']
        if 'parent_open_id' in d:
            o.parent_open_id = d['parent_open_id']
        if 'parent_uid' in d:
            o.parent_uid = d['parent_uid']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'school_id' in d:
            o.school_id = d['school_id']
        if 'student_no' in d:
            o.student_no = d['student_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundEnterprisepaySignModel(object):

    def __init__(self):
        self._account_name = None
        self._appoint_sign_terminal = None
        self._biz_scene = None
        self._ext_params = None
        self._identity = None
        self._identity_name = None
        self._identity_type = None
        self._out_biz_no = None
        self._out_entity_id = None
        self._out_source = None
        self._product_code = None

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def appoint_sign_terminal(self):
        return self._appoint_sign_terminal

    @appoint_sign_terminal.setter
    def appoint_sign_terminal(self, value):
        self._appoint_sign_terminal = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def ext_params(self):
        return self._ext_params

    @ext_params.setter
    def ext_params(self, value):
        self._ext_params = value
    @property
    def identity(self):
        return self._identity

    @identity.setter
    def identity(self, value):
        self._identity = value
    @property
    def identity_name(self):
        return self._identity_name

    @identity_name.setter
    def identity_name(self, value):
        self._identity_name = value
    @property
    def identity_type(self):
        return self._identity_type

    @identity_type.setter
    def identity_type(self, value):
        self._identity_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_entity_id(self):
        return self._out_entity_id

    @out_entity_id.setter
    def out_entity_id(self, value):
        self._out_entity_id = value
    @property
    def out_source(self):
        return self._out_source

    @out_source.setter
    def out_source(self, value):
        self._out_source = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_name:
            if hasattr(self.account_name, 'to_alipay_dict'):
                params['account_name'] = self.account_name.to_alipay_dict()
            else:
                params['account_name'] = self.account_name
        if self.appoint_sign_terminal:
            if hasattr(self.appoint_sign_terminal, 'to_alipay_dict'):
                params['appoint_sign_terminal'] = self.appoint_sign_terminal.to_alipay_dict()
            else:
                params['appoint_sign_terminal'] = self.appoint_sign_terminal
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.ext_params:
            if hasattr(self.ext_params, 'to_alipay_dict'):
                params['ext_params'] = self.ext_params.to_alipay_dict()
            else:
                params['ext_params'] = self.ext_params
        if self.identity:
            if hasattr(self.identity, 'to_alipay_dict'):
                params['identity'] = self.identity.to_alipay_dict()
            else:
                params['identity'] = self.identity
        if self.identity_name:
            if hasattr(self.identity_name, 'to_alipay_dict'):
                params['identity_name'] = self.identity_name.to_alipay_dict()
            else:
                params['identity_name'] = self.identity_name
        if self.identity_type:
            if hasattr(self.identity_type, 'to_alipay_dict'):
                params['identity_type'] = self.identity_type.to_alipay_dict()
            else:
                params['identity_type'] = self.identity_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_entity_id:
            if hasattr(self.out_entity_id, 'to_alipay_dict'):
                params['out_entity_id'] = self.out_entity_id.to_alipay_dict()
            else:
                params['out_entity_id'] = self.out_entity_id
        if self.out_source:
            if hasattr(self.out_source, 'to_alipay_dict'):
                params['out_source'] = self.out_source.to_alipay_dict()
            else:
                params['out_source'] = self.out_source
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundEnterprisepaySignModel()
        if 'account_name' in d:
            o.account_name = d['account_name']
        if 'appoint_sign_terminal' in d:
            o.appoint_sign_terminal = d['appoint_sign_terminal']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'ext_params' in d:
            o.ext_params = d['ext_params']
        if 'identity' in d:
            o.identity = d['identity']
        if 'identity_name' in d:
            o.identity_name = d['identity_name']
        if 'identity_type' in d:
            o.identity_type = d['identity_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_entity_id' in d:
            o.out_entity_id = d['out_entity_id']
        if 'out_source' in d:
            o.out_source = d['out_source']
        if 'product_code' in d:
            o.product_code = d['product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.JinyoutestopenidTwo import JinyoutestopenidTwo


class JinyoutestopenidThree(object):

    def __init__(self):
        self._a = None
        self._b = None
        self._b_open_id = None
        self._f = None

    @property
    def a(self):
        return self._a

    @a.setter
    def a(self, value):
        self._a = value
    @property
    def b(self):
        return self._b

    @b.setter
    def b(self, value):
        self._b = value
    @property
    def b_open_id(self):
        return self._b_open_id

    @b_open_id.setter
    def b_open_id(self, value):
        self._b_open_id = value
    @property
    def f(self):
        return self._f

    @f.setter
    def f(self, value):
        if isinstance(value, JinyoutestopenidTwo):
            self._f = value
        else:
            self._f = JinyoutestopenidTwo.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.a:
            if hasattr(self.a, 'to_alipay_dict'):
                params['a'] = self.a.to_alipay_dict()
            else:
                params['a'] = self.a
        if self.b:
            if hasattr(self.b, 'to_alipay_dict'):
                params['b'] = self.b.to_alipay_dict()
            else:
                params['b'] = self.b
        if self.b_open_id:
            if hasattr(self.b_open_id, 'to_alipay_dict'):
                params['b_open_id'] = self.b_open_id.to_alipay_dict()
            else:
                params['b_open_id'] = self.b_open_id
        if self.f:
            if hasattr(self.f, 'to_alipay_dict'):
                params['f'] = self.f.to_alipay_dict()
            else:
                params['f'] = self.f
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JinyoutestopenidThree()
        if 'a' in d:
            o.a = d['a']
        if 'b' in d:
            o.b = d['b']
        if 'b_open_id' in d:
            o.b_open_id = d['b_open_id']
        if 'f' in d:
            o.f = d['f']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotReceiptSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotReceiptSendResponse, self).__init__()
        self._ext_info = None
        self._receipt_id = None
        self._ret_code = None
        self._ret_code_sub = None
        self._ret_message = None
        self._ret_message_sub = None
        self._success = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def receipt_id(self):
        return self._receipt_id

    @receipt_id.setter
    def receipt_id(self, value):
        self._receipt_id = value
    @property
    def ret_code(self):
        return self._ret_code

    @ret_code.setter
    def ret_code(self, value):
        self._ret_code = value
    @property
    def ret_code_sub(self):
        return self._ret_code_sub

    @ret_code_sub.setter
    def ret_code_sub(self, value):
        self._ret_code_sub = value
    @property
    def ret_message(self):
        return self._ret_message

    @ret_message.setter
    def ret_message(self, value):
        self._ret_message = value
    @property
    def ret_message_sub(self):
        return self._ret_message_sub

    @ret_message_sub.setter
    def ret_message_sub(self, value):
        self._ret_message_sub = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotReceiptSendResponse, self).parse_response_content(response_content)
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'receipt_id' in response:
            self.receipt_id = response['receipt_id']
        if 'ret_code' in response:
            self.ret_code = response['ret_code']
        if 'ret_code_sub' in response:
            self.ret_code_sub = response['ret_code_sub']
        if 'ret_message' in response:
            self.ret_message = response['ret_message']
        if 'ret_message_sub' in response:
            self.ret_message_sub = response['ret_message_sub']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DatadigitalFincloudFinsaasDesignPageBatchqueryModel(object):

    def __init__(self):
        self._creator_name = None
        self._page_name = None
        self._page_num = None
        self._page_size = None
        self._status = None
        self._tenant_code = None

    @property
    def creator_name(self):
        return self._creator_name

    @creator_name.setter
    def creator_name(self, value):
        self._creator_name = value
    @property
    def page_name(self):
        return self._page_name

    @page_name.setter
    def page_name(self, value):
        self._page_name = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.creator_name:
            if hasattr(self.creator_name, 'to_alipay_dict'):
                params['creator_name'] = self.creator_name.to_alipay_dict()
            else:
                params['creator_name'] = self.creator_name
        if self.page_name:
            if hasattr(self.page_name, 'to_alipay_dict'):
                params['page_name'] = self.page_name.to_alipay_dict()
            else:
                params['page_name'] = self.page_name
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasDesignPageBatchqueryModel()
        if 'creator_name' in d:
            o.creator_name = d['creator_name']
        if 'page_name' in d:
            o.page_name = d['page_name']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'status' in d:
            o.status = d['status']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityRiskCustomerriskQueryModel(object):

    def __init__(self):
        self._bank_card_no = None
        self._business_license_no = None
        self._card_no = None
        self._cert_no = None
        self._company_name = None
        self._external_id = None
        self._mobile_no = None
        self._open_id = None
        self._risk_type = None
        self._user_id = None

    @property
    def bank_card_no(self):
        return self._bank_card_no

    @bank_card_no.setter
    def bank_card_no(self, value):
        self._bank_card_no = value
    @property
    def business_license_no(self):
        return self._business_license_no

    @business_license_no.setter
    def business_license_no(self, value):
        self._business_license_no = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def mobile_no(self):
        return self._mobile_no

    @mobile_no.setter
    def mobile_no(self, value):
        self._mobile_no = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def risk_type(self):
        return self._risk_type

    @risk_type.setter
    def risk_type(self, value):
        self._risk_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bank_card_no:
            if hasattr(self.bank_card_no, 'to_alipay_dict'):
                params['bank_card_no'] = self.bank_card_no.to_alipay_dict()
            else:
                params['bank_card_no'] = self.bank_card_no
        if self.business_license_no:
            if hasattr(self.business_license_no, 'to_alipay_dict'):
                params['business_license_no'] = self.business_license_no.to_alipay_dict()
            else:
                params['business_license_no'] = self.business_license_no
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.mobile_no:
            if hasattr(self.mobile_no, 'to_alipay_dict'):
                params['mobile_no'] = self.mobile_no.to_alipay_dict()
            else:
                params['mobile_no'] = self.mobile_no
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.risk_type:
            if hasattr(self.risk_type, 'to_alipay_dict'):
                params['risk_type'] = self.risk_type.to_alipay_dict()
            else:
                params['risk_type'] = self.risk_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskCustomerriskQueryModel()
        if 'bank_card_no' in d:
            o.bank_card_no = d['bank_card_no']
        if 'business_license_no' in d:
            o.business_license_no = d['business_license_no']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'mobile_no' in d:
            o.mobile_no = d['mobile_no']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'risk_type' in d:
            o.risk_type = d['risk_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbAdvertModifyChannelRequest(object):

    def __init__(self):
        self._channel_id = None
        self._memo = None
        self._name = None

    @property
    def channel_id(self):
        return self._channel_id

    @channel_id.setter
    def channel_id(self, value):
        self._channel_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_id:
            if hasattr(self.channel_id, 'to_alipay_dict'):
                params['channel_id'] = self.channel_id.to_alipay_dict()
            else:
                params['channel_id'] = self.channel_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertModifyChannelRequest()
        if 'channel_id' in d:
            o.channel_id = d['channel_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ClearingCommonResult(object):

    def __init__(self):
        self._result_code = None
        self._result_description = None
        self._success = None

    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_description(self):
        return self._result_description

    @result_description.setter
    def result_description(self, value):
        self._result_description = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.result_code:
            if hasattr(self.result_code, 'to_alipay_dict'):
                params['result_code'] = self.result_code.to_alipay_dict()
            else:
                params['result_code'] = self.result_code
        if self.result_description:
            if hasattr(self.result_description, 'to_alipay_dict'):
                params['result_description'] = self.result_description.to_alipay_dict()
            else:
                params['result_description'] = self.result_description
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ClearingCommonResult()
        if 'result_code' in d:
            o.result_code = d['result_code']
        if 'result_description' in d:
            o.result_description = d['result_description']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingConfigQueryModel(object):

    def __init__(self):
        self._interface_name = None
        self._interface_type = None

    @property
    def interface_name(self):
        return self._interface_name

    @interface_name.setter
    def interface_name(self, value):
        self._interface_name = value
    @property
    def interface_type(self):
        return self._interface_type

    @interface_type.setter
    def interface_type(self, value):
        self._interface_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.interface_name:
            if hasattr(self.interface_name, 'to_alipay_dict'):
                params['interface_name'] = self.interface_name.to_alipay_dict()
            else:
                params['interface_name'] = self.interface_name
        if self.interface_type:
            if hasattr(self.interface_type, 'to_alipay_dict'):
                params['interface_type'] = self.interface_type.to_alipay_dict()
            else:
                params['interface_type'] = self.interface_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingConfigQueryModel()
        if 'interface_name' in d:
            o.interface_name = d['interface_name']
        if 'interface_type' in d:
            o.interface_type = d['interface_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundJointaccountBillQueryModel(object):

    def __init__(self):
        self._account_id = None
        self._agreement_no = None
        self._biz_scene = None
        self._end_date = None
        self._open_id = None
        self._page_num = None
        self._page_size = None
        self._product_code = None
        self._start_date = None
        self._user_id = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundJointaccountBillQueryModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TagOptionCategoryOpenDetail import TagOptionCategoryOpenDetail


class SelectTagOptionOpenCategory(object):

    def __init__(self):
        self._options = None
        self._tag_option_category_id = None
        self._tag_option_category_name = None
        self._type = None

    @property
    def options(self):
        return self._options

    @options.setter
    def options(self, value):
        if isinstance(value, TagOptionCategoryOpenDetail):
            self._options = value
        else:
            self._options = TagOptionCategoryOpenDetail.from_alipay_dict(value)
    @property
    def tag_option_category_id(self):
        return self._tag_option_category_id

    @tag_option_category_id.setter
    def tag_option_category_id(self, value):
        self._tag_option_category_id = value
    @property
    def tag_option_category_name(self):
        return self._tag_option_category_name

    @tag_option_category_name.setter
    def tag_option_category_name(self, value):
        self._tag_option_category_name = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.options:
            if hasattr(self.options, 'to_alipay_dict'):
                params['options'] = self.options.to_alipay_dict()
            else:
                params['options'] = self.options
        if self.tag_option_category_id:
            if hasattr(self.tag_option_category_id, 'to_alipay_dict'):
                params['tag_option_category_id'] = self.tag_option_category_id.to_alipay_dict()
            else:
                params['tag_option_category_id'] = self.tag_option_category_id
        if self.tag_option_category_name:
            if hasattr(self.tag_option_category_name, 'to_alipay_dict'):
                params['tag_option_category_name'] = self.tag_option_category_name.to_alipay_dict()
            else:
                params['tag_option_category_name'] = self.tag_option_category_name
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SelectTagOptionOpenCategory()
        if 'options' in d:
            o.options = d['options']
        if 'tag_option_category_id' in d:
            o.tag_option_category_id = d['tag_option_category_id']
        if 'tag_option_category_name' in d:
            o.tag_option_category_name = d['tag_option_category_name']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SignPartyOpenApiDTO import SignPartyOpenApiDTO


class SignPartyGroupOpenApiDTO(object):

    def __init__(self):
        self._sign_parties = None

    @property
    def sign_parties(self):
        return self._sign_parties

    @sign_parties.setter
    def sign_parties(self, value):
        if isinstance(value, list):
            self._sign_parties = list()
            for i in value:
                if isinstance(i, SignPartyOpenApiDTO):
                    self._sign_parties.append(i)
                else:
                    self._sign_parties.append(SignPartyOpenApiDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.sign_parties:
            if isinstance(self.sign_parties, list):
                for i in range(0, len(self.sign_parties)):
                    element = self.sign_parties[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sign_parties[i] = element.to_alipay_dict()
            if hasattr(self.sign_parties, 'to_alipay_dict'):
                params['sign_parties'] = self.sign_parties.to_alipay_dict()
            else:
                params['sign_parties'] = self.sign_parties
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignPartyGroupOpenApiDTO()
        if 'sign_parties' in d:
            o.sign_parties = d['sign_parties']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossProdAntsignDetailQueryModel(object):

    def __init__(self):
        self._app_name = None
        self._biz_no = None
        self._business_line_code = None
        self._scene_code = None
        self._sign_flow_id = None
        self._sign_task_id = None
        self._tenant = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def business_line_code(self):
        return self._business_line_code

    @business_line_code.setter
    def business_line_code(self, value):
        self._business_line_code = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def sign_flow_id(self):
        return self._sign_flow_id

    @sign_flow_id.setter
    def sign_flow_id(self, value):
        self._sign_flow_id = value
    @property
    def sign_task_id(self):
        return self._sign_task_id

    @sign_task_id.setter
    def sign_task_id(self, value):
        self._sign_task_id = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.business_line_code:
            if hasattr(self.business_line_code, 'to_alipay_dict'):
                params['business_line_code'] = self.business_line_code.to_alipay_dict()
            else:
                params['business_line_code'] = self.business_line_code
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.sign_flow_id:
            if hasattr(self.sign_flow_id, 'to_alipay_dict'):
                params['sign_flow_id'] = self.sign_flow_id.to_alipay_dict()
            else:
                params['sign_flow_id'] = self.sign_flow_id
        if self.sign_task_id:
            if hasattr(self.sign_task_id, 'to_alipay_dict'):
                params['sign_task_id'] = self.sign_task_id.to_alipay_dict()
            else:
                params['sign_task_id'] = self.sign_task_id
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdAntsignDetailQueryModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'business_line_code' in d:
            o.business_line_code = d['business_line_code']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'sign_flow_id' in d:
            o.sign_flow_id = d['sign_flow_id']
        if 'sign_task_id' in d:
            o.sign_task_id = d['sign_task_id']
        if 'tenant' in d:
            o.tenant = d['tenant']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceEcEnterpriseUnsignResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceEcEnterpriseUnsignResponse, self).__init__()
        self._account_id = None
        self._enterprise_id = None
        self._unsign_url = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def enterprise_id(self):
        return self._enterprise_id

    @enterprise_id.setter
    def enterprise_id(self, value):
        self._enterprise_id = value
    @property
    def unsign_url(self):
        return self._unsign_url

    @unsign_url.setter
    def unsign_url(self, value):
        self._unsign_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceEcEnterpriseUnsignResponse, self).parse_response_content(response_content)
        if 'account_id' in response:
            self.account_id = response['account_id']
        if 'enterprise_id' in response:
            self.enterprise_id = response['enterprise_id']
        if 'unsign_url' in response:
            self.unsign_url = response['unsign_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZMGORightConfig(object):

    def __init__(self):
        self._cumulative_preferential_redirect_schema = None
        self._custom_benefit_desc = None
        self._custom_sub_benefit_desc = None

    @property
    def cumulative_preferential_redirect_schema(self):
        return self._cumulative_preferential_redirect_schema

    @cumulative_preferential_redirect_schema.setter
    def cumulative_preferential_redirect_schema(self, value):
        self._cumulative_preferential_redirect_schema = value
    @property
    def custom_benefit_desc(self):
        return self._custom_benefit_desc

    @custom_benefit_desc.setter
    def custom_benefit_desc(self, value):
        self._custom_benefit_desc = value
    @property
    def custom_sub_benefit_desc(self):
        return self._custom_sub_benefit_desc

    @custom_sub_benefit_desc.setter
    def custom_sub_benefit_desc(self, value):
        self._custom_sub_benefit_desc = value


    def to_alipay_dict(self):
        params = dict()
        if self.cumulative_preferential_redirect_schema:
            if hasattr(self.cumulative_preferential_redirect_schema, 'to_alipay_dict'):
                params['cumulative_preferential_redirect_schema'] = self.cumulative_preferential_redirect_schema.to_alipay_dict()
            else:
                params['cumulative_preferential_redirect_schema'] = self.cumulative_preferential_redirect_schema
        if self.custom_benefit_desc:
            if hasattr(self.custom_benefit_desc, 'to_alipay_dict'):
                params['custom_benefit_desc'] = self.custom_benefit_desc.to_alipay_dict()
            else:
                params['custom_benefit_desc'] = self.custom_benefit_desc
        if self.custom_sub_benefit_desc:
            if hasattr(self.custom_sub_benefit_desc, 'to_alipay_dict'):
                params['custom_sub_benefit_desc'] = self.custom_sub_benefit_desc.to_alipay_dict()
            else:
                params['custom_sub_benefit_desc'] = self.custom_sub_benefit_desc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZMGORightConfig()
        if 'cumulative_preferential_redirect_schema' in d:
            o.cumulative_preferential_redirect_schema = d['cumulative_preferential_redirect_schema']
        if 'custom_benefit_desc' in d:
            o.custom_benefit_desc = d['custom_benefit_desc']
        if 'custom_sub_benefit_desc' in d:
            o.custom_sub_benefit_desc = d['custom_sub_benefit_desc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ParticipantInfo import ParticipantInfo


class AlipayCommerceEducateCompetitionapplyStatusSyncModel(object):

    def __init__(self):
        self._apply_note_info = None
        self._apply_status = None
        self._extend_info = None
        self._from_code = None
        self._participant_id = None
        self._participant_info = None
        self._source_id = None

    @property
    def apply_note_info(self):
        return self._apply_note_info

    @apply_note_info.setter
    def apply_note_info(self, value):
        self._apply_note_info = value
    @property
    def apply_status(self):
        return self._apply_status

    @apply_status.setter
    def apply_status(self, value):
        self._apply_status = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def from_code(self):
        return self._from_code

    @from_code.setter
    def from_code(self, value):
        self._from_code = value
    @property
    def participant_id(self):
        return self._participant_id

    @participant_id.setter
    def participant_id(self, value):
        self._participant_id = value
    @property
    def participant_info(self):
        return self._participant_info

    @participant_info.setter
    def participant_info(self, value):
        if isinstance(value, ParticipantInfo):
            self._participant_info = value
        else:
            self._participant_info = ParticipantInfo.from_alipay_dict(value)
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_note_info:
            if hasattr(self.apply_note_info, 'to_alipay_dict'):
                params['apply_note_info'] = self.apply_note_info.to_alipay_dict()
            else:
                params['apply_note_info'] = self.apply_note_info
        if self.apply_status:
            if hasattr(self.apply_status, 'to_alipay_dict'):
                params['apply_status'] = self.apply_status.to_alipay_dict()
            else:
                params['apply_status'] = self.apply_status
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.from_code:
            if hasattr(self.from_code, 'to_alipay_dict'):
                params['from_code'] = self.from_code.to_alipay_dict()
            else:
                params['from_code'] = self.from_code
        if self.participant_id:
            if hasattr(self.participant_id, 'to_alipay_dict'):
                params['participant_id'] = self.participant_id.to_alipay_dict()
            else:
                params['participant_id'] = self.participant_id
        if self.participant_info:
            if hasattr(self.participant_info, 'to_alipay_dict'):
                params['participant_info'] = self.participant_info.to_alipay_dict()
            else:
                params['participant_info'] = self.participant_info
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateCompetitionapplyStatusSyncModel()
        if 'apply_note_info' in d:
            o.apply_note_info = d['apply_note_info']
        if 'apply_status' in d:
            o.apply_status = d['apply_status']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'from_code' in d:
            o.from_code = d['from_code']
        if 'participant_id' in d:
            o.participant_id = d['participant_id']
        if 'participant_info' in d:
            o.participant_info = d['participant_info']
        if 'source_id' in d:
            o.source_id = d['source_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Marketingtest import Marketingtest


class Marketingtestt(object):

    def __init__(self):
        self._test_22 = None

    @property
    def test_22(self):
        return self._test_22

    @test_22.setter
    def test_22(self, value):
        if isinstance(value, Marketingtest):
            self._test_22 = value
        else:
            self._test_22 = Marketingtest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.test_22:
            if hasattr(self.test_22, 'to_alipay_dict'):
                params['test_22'] = self.test_22.to_alipay_dict()
            else:
                params['test_22'] = self.test_22
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Marketingtestt()
        if 'test_22' in d:
            o.test_22 = d['test_22']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SupportFunction(object):

    def __init__(self):
        self._card_name = None
        self._card_type = None
        self._function_type = None
        self._goto_url = None

    @property
    def card_name(self):
        return self._card_name

    @card_name.setter
    def card_name(self, value):
        self._card_name = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def function_type(self):
        return self._function_type

    @function_type.setter
    def function_type(self, value):
        if isinstance(value, list):
            self._function_type = list()
            for i in value:
                self._function_type.append(i)
    @property
    def goto_url(self):
        return self._goto_url

    @goto_url.setter
    def goto_url(self, value):
        self._goto_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_name:
            if hasattr(self.card_name, 'to_alipay_dict'):
                params['card_name'] = self.card_name.to_alipay_dict()
            else:
                params['card_name'] = self.card_name
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.function_type:
            if isinstance(self.function_type, list):
                for i in range(0, len(self.function_type)):
                    element = self.function_type[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.function_type[i] = element.to_alipay_dict()
            if hasattr(self.function_type, 'to_alipay_dict'):
                params['function_type'] = self.function_type.to_alipay_dict()
            else:
                params['function_type'] = self.function_type
        if self.goto_url:
            if hasattr(self.goto_url, 'to_alipay_dict'):
                params['goto_url'] = self.goto_url.to_alipay_dict()
            else:
                params['goto_url'] = self.goto_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SupportFunction()
        if 'card_name' in d:
            o.card_name = d['card_name']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'function_type' in d:
            o.function_type = d['function_type']
        if 'goto_url' in d:
            o.goto_url = d['goto_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DepartmentDTO(object):

    def __init__(self):
        self._biz_type = None
        self._dept_id = None
        self._dept_name = None
        self._dept_path = None
        self._label_code = None
        self._label_name = None
        self._parent_dept_id = None
        self._shop_id = None
        self._type = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def dept_id(self):
        return self._dept_id

    @dept_id.setter
    def dept_id(self, value):
        self._dept_id = value
    @property
    def dept_name(self):
        return self._dept_name

    @dept_name.setter
    def dept_name(self, value):
        self._dept_name = value
    @property
    def dept_path(self):
        return self._dept_path

    @dept_path.setter
    def dept_path(self, value):
        self._dept_path = value
    @property
    def label_code(self):
        return self._label_code

    @label_code.setter
    def label_code(self, value):
        self._label_code = value
    @property
    def label_name(self):
        return self._label_name

    @label_name.setter
    def label_name(self, value):
        self._label_name = value
    @property
    def parent_dept_id(self):
        return self._parent_dept_id

    @parent_dept_id.setter
    def parent_dept_id(self, value):
        self._parent_dept_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.dept_id:
            if hasattr(self.dept_id, 'to_alipay_dict'):
                params['dept_id'] = self.dept_id.to_alipay_dict()
            else:
                params['dept_id'] = self.dept_id
        if self.dept_name:
            if hasattr(self.dept_name, 'to_alipay_dict'):
                params['dept_name'] = self.dept_name.to_alipay_dict()
            else:
                params['dept_name'] = self.dept_name
        if self.dept_path:
            if hasattr(self.dept_path, 'to_alipay_dict'):
                params['dept_path'] = self.dept_path.to_alipay_dict()
            else:
                params['dept_path'] = self.dept_path
        if self.label_code:
            if hasattr(self.label_code, 'to_alipay_dict'):
                params['label_code'] = self.label_code.to_alipay_dict()
            else:
                params['label_code'] = self.label_code
        if self.label_name:
            if hasattr(self.label_name, 'to_alipay_dict'):
                params['label_name'] = self.label_name.to_alipay_dict()
            else:
                params['label_name'] = self.label_name
        if self.parent_dept_id:
            if hasattr(self.parent_dept_id, 'to_alipay_dict'):
                params['parent_dept_id'] = self.parent_dept_id.to_alipay_dict()
            else:
                params['parent_dept_id'] = self.parent_dept_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DepartmentDTO()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'dept_id' in d:
            o.dept_id = d['dept_id']
        if 'dept_name' in d:
            o.dept_name = d['dept_name']
        if 'dept_path' in d:
            o.dept_path = d['dept_path']
        if 'label_code' in d:
            o.label_code = d['label_code']
        if 'label_name' in d:
            o.label_name = d['label_name']
        if 'parent_dept_id' in d:
            o.parent_dept_id = d['parent_dept_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingVoucherStockQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingVoucherStockQueryResponse, self).__init__()
        self._available_count = None
        self._total_count = None

    @property
    def available_count(self):
        return self._available_count

    @available_count.setter
    def available_count(self, value):
        self._available_count = value
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingVoucherStockQueryResponse, self).parse_response_content(response_content)
        if 'available_count' in response:
            self.available_count = response['available_count']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsPeriodDTO import InsPeriodDTO


class InsQuoteDTO(object):

    def __init__(self):
        self._discount_rate = None
        self._ins_period = None
        self._inst_id = None
        self._original_premium = None
        self._premium = None
        self._premium_rate = None
        self._product_code = None
        self._product_name = None
        self._product_plan_id = None
        self._quote_id = None
        self._recommend_flow_id = None
        self._sum_insured = None

    @property
    def discount_rate(self):
        return self._discount_rate

    @discount_rate.setter
    def discount_rate(self, value):
        self._discount_rate = value
    @property
    def ins_period(self):
        return self._ins_period

    @ins_period.setter
    def ins_period(self, value):
        if isinstance(value, InsPeriodDTO):
            self._ins_period = value
        else:
            self._ins_period = InsPeriodDTO.from_alipay_dict(value)
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def original_premium(self):
        return self._original_premium

    @original_premium.setter
    def original_premium(self, value):
        self._original_premium = value
    @property
    def premium(self):
        return self._premium

    @premium.setter
    def premium(self, value):
        self._premium = value
    @property
    def premium_rate(self):
        return self._premium_rate

    @premium_rate.setter
    def premium_rate(self, value):
        self._premium_rate = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value
    @property
    def product_plan_id(self):
        return self._product_plan_id

    @product_plan_id.setter
    def product_plan_id(self, value):
        self._product_plan_id = value
    @property
    def quote_id(self):
        return self._quote_id

    @quote_id.setter
    def quote_id(self, value):
        self._quote_id = value
    @property
    def recommend_flow_id(self):
        return self._recommend_flow_id

    @recommend_flow_id.setter
    def recommend_flow_id(self, value):
        self._recommend_flow_id = value
    @property
    def sum_insured(self):
        return self._sum_insured

    @sum_insured.setter
    def sum_insured(self, value):
        self._sum_insured = value


    def to_alipay_dict(self):
        params = dict()
        if self.discount_rate:
            if hasattr(self.discount_rate, 'to_alipay_dict'):
                params['discount_rate'] = self.discount_rate.to_alipay_dict()
            else:
                params['discount_rate'] = self.discount_rate
        if self.ins_period:
            if hasattr(self.ins_period, 'to_alipay_dict'):
                params['ins_period'] = self.ins_period.to_alipay_dict()
            else:
                params['ins_period'] = self.ins_period
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.original_premium:
            if hasattr(self.original_premium, 'to_alipay_dict'):
                params['original_premium'] = self.original_premium.to_alipay_dict()
            else:
                params['original_premium'] = self.original_premium
        if self.premium:
            if hasattr(self.premium, 'to_alipay_dict'):
                params['premium'] = self.premium.to_alipay_dict()
            else:
                params['premium'] = self.premium
        if self.premium_rate:
            if hasattr(self.premium_rate, 'to_alipay_dict'):
                params['premium_rate'] = self.premium_rate.to_alipay_dict()
            else:
                params['premium_rate'] = self.premium_rate
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        if self.product_plan_id:
            if hasattr(self.product_plan_id, 'to_alipay_dict'):
                params['product_plan_id'] = self.product_plan_id.to_alipay_dict()
            else:
                params['product_plan_id'] = self.product_plan_id
        if self.quote_id:
            if hasattr(self.quote_id, 'to_alipay_dict'):
                params['quote_id'] = self.quote_id.to_alipay_dict()
            else:
                params['quote_id'] = self.quote_id
        if self.recommend_flow_id:
            if hasattr(self.recommend_flow_id, 'to_alipay_dict'):
                params['recommend_flow_id'] = self.recommend_flow_id.to_alipay_dict()
            else:
                params['recommend_flow_id'] = self.recommend_flow_id
        if self.sum_insured:
            if hasattr(self.sum_insured, 'to_alipay_dict'):
                params['sum_insured'] = self.sum_insured.to_alipay_dict()
            else:
                params['sum_insured'] = self.sum_insured
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsQuoteDTO()
        if 'discount_rate' in d:
            o.discount_rate = d['discount_rate']
        if 'ins_period' in d:
            o.ins_period = d['ins_period']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'original_premium' in d:
            o.original_premium = d['original_premium']
        if 'premium' in d:
            o.premium = d['premium']
        if 'premium_rate' in d:
            o.premium_rate = d['premium_rate']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'product_name' in d:
            o.product_name = d['product_name']
        if 'product_plan_id' in d:
            o.product_plan_id = d['product_plan_id']
        if 'quote_id' in d:
            o.quote_id = d['quote_id']
        if 'recommend_flow_id' in d:
            o.recommend_flow_id = d['recommend_flow_id']
        if 'sum_insured' in d:
            o.sum_insured = d['sum_insured']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TradeRequestVO(object):

    def __init__(self):
        self._acquirer = None
        self._acquirer_mem_id = None
        self._aml_status = None
        self._biz_ev_code = None
        self._biz_pd_code = None
        self._client_advice_timestamp = None
        self._client_business_id = None
        self._client_id = None
        self._client_message_id = None
        self._client_ref = None
        self._client_system = None
        self._cnl_ev_code = None
        self._cnl_no = None
        self._cnl_pd_code = None
        self._contra_amount = None
        self._contra_ccy = None
        self._extension = None
        self._inst_entity = None
        self._is_locked = None
        self._issuer = None
        self._issuer_mem_id = None
        self._merchant_mcc = None
        self._msg_type = None
        self._operate_type = None
        self._partial_trade = None
        self._partner_id = None
        self._payment_provider = None
        self._payment_type = None
        self._product_id = None
        self._profile_id = None
        self._rate_base_ccy = None
        self._rate_ref = None
        self._rate_request_mode = None
        self._rate_type = None
        self._reference_field1 = None
        self._reference_field2 = None
        self._reference_field3 = None
        self._related_message_id = None
        self._request_message_id = None
        self._requested_rate = None
        self._settlement_amount = None
        self._settlement_ccy = None
        self._side = None
        self._slip_point = None
        self._time_zone = None
        self._tnt_inst_id = None
        self._trade_timestamp = None
        self._trade_type = None
        self._transaction_amount = None
        self._transaction_ccy = None
        self._transaction_ccy_type = None
        self._transaction_type = None
        self._user_id = None
        self._value_date = None

    @property
    def acquirer(self):
        return self._acquirer

    @acquirer.setter
    def acquirer(self, value):
        self._acquirer = value
    @property
    def acquirer_mem_id(self):
        return self._acquirer_mem_id

    @acquirer_mem_id.setter
    def acquirer_mem_id(self, value):
        self._acquirer_mem_id = value
    @property
    def aml_status(self):
        return self._aml_status

    @aml_status.setter
    def aml_status(self, value):
        self._aml_status = value
    @property
    def biz_ev_code(self):
        return self._biz_ev_code

    @biz_ev_code.setter
    def biz_ev_code(self, value):
        self._biz_ev_code = value
    @property
    def biz_pd_code(self):
        return self._biz_pd_code

    @biz_pd_code.setter
    def biz_pd_code(self, value):
        self._biz_pd_code = value
    @property
    def client_advice_timestamp(self):
        return self._client_advice_timestamp

    @client_advice_timestamp.setter
    def client_advice_timestamp(self, value):
        self._client_advice_timestamp = value
    @property
    def client_business_id(self):
        return self._client_business_id

    @client_business_id.setter
    def client_business_id(self, value):
        self._client_business_id = value
    @property
    def client_id(self):
        return self._client_id

    @client_id.setter
    def client_id(self, value):
        self._client_id = value
    @property
    def client_message_id(self):
        return self._client_message_id

    @client_message_id.setter
    def client_message_id(self, value):
        self._client_message_id = value
    @property
    def client_ref(self):
        return self._client_ref

    @client_ref.setter
    def client_ref(self, value):
        self._client_ref = value
    @property
    def client_system(self):
        return self._client_system

    @client_system.setter
    def client_system(self, value):
        self._client_system = value
    @property
    def cnl_ev_code(self):
        return self._cnl_ev_code

    @cnl_ev_code.setter
    def cnl_ev_code(self, value):
        self._cnl_ev_code = value
    @property
    def cnl_no(self):
        return self._cnl_no

    @cnl_no.setter
    def cnl_no(self, value):
        self._cnl_no = value
    @property
    def cnl_pd_code(self):
        return self._cnl_pd_code

    @cnl_pd_code.setter
    def cnl_pd_code(self, value):
        self._cnl_pd_code = value
    @property
    def contra_amount(self):
        return self._contra_amount

    @contra_amount.setter
    def contra_amount(self, value):
        self._contra_amount = value
    @property
    def contra_ccy(self):
        return self._contra_ccy

    @contra_ccy.setter
    def contra_ccy(self, value):
        self._contra_ccy = value
    @property
    def extension(self):
        return self._extension

    @extension.setter
    def extension(self, value):
        self._extension = value
    @property
    def inst_entity(self):
        return self._inst_entity

    @inst_entity.setter
    def inst_entity(self, value):
        self._inst_entity = value
    @property
    def is_locked(self):
        return self._is_locked

    @is_locked.setter
    def is_locked(self, value):
        self._is_locked = value
    @property
    def issuer(self):
        return self._issuer

    @issuer.setter
    def issuer(self, value):
        self._issuer = value
    @property
    def issuer_mem_id(self):
        return self._issuer_mem_id

    @issuer_mem_id.setter
    def issuer_mem_id(self, value):
        self._issuer_mem_id = value
    @property
    def merchant_mcc(self):
        return self._merchant_mcc

    @merchant_mcc.setter
    def merchant_mcc(self, value):
        self._merchant_mcc = value
    @property
    def msg_type(self):
        return self._msg_type

    @msg_type.setter
    def msg_type(self, value):
        self._msg_type = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value
    @property
    def partial_trade(self):
        return self._partial_trade

    @partial_trade.setter
    def partial_trade(self, value):
        self._partial_trade = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def payment_provider(self):
        return self._payment_provider

    @payment_provider.setter
    def payment_provider(self, value):
        self._payment_provider = value
    @property
    def payment_type(self):
        return self._payment_type

    @payment_type.setter
    def payment_type(self, value):
        self._payment_type = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        self._product_id = value
    @property
    def profile_id(self):
        return self._profile_id

    @profile_id.setter
    def profile_id(self, value):
        self._profile_id = value
    @property
    def rate_base_ccy(self):
        return self._rate_base_ccy

    @rate_base_ccy.setter
    def rate_base_ccy(self, value):
        self._rate_base_ccy = value
    @property
    def rate_ref(self):
        return self._rate_ref

    @rate_ref.setter
    def rate_ref(self, value):
        self._rate_ref = value
    @property
    def rate_request_mode(self):
        return self._rate_request_mode

    @rate_request_mode.setter
    def rate_request_mode(self, value):
        self._rate_request_mode = value
    @property
    def rate_type(self):
        return self._rate_type

    @rate_type.setter
    def rate_type(self, value):
        self._rate_type = value
    @property
    def reference_field1(self):
        return self._reference_field1

    @reference_field1.setter
    def reference_field1(self, value):
        self._reference_field1 = value
    @property
    def reference_field2(self):
        return self._reference_field2

    @reference_field2.setter
    def reference_field2(self, value):
        self._reference_field2 = value
    @property
    def reference_field3(self):
        return self._reference_field3

    @reference_field3.setter
    def reference_field3(self, value):
        self._reference_field3 = value
    @property
    def related_message_id(self):
        return self._related_message_id

    @related_message_id.setter
    def related_message_id(self, value):
        self._related_message_id = value
    @property
    def request_message_id(self):
        return self._request_message_id

    @request_message_id.setter
    def request_message_id(self, value):
        self._request_message_id = value
    @property
    def requested_rate(self):
        return self._requested_rate

    @requested_rate.setter
    def requested_rate(self, value):
        self._requested_rate = value
    @property
    def settlement_amount(self):
        return self._settlement_amount

    @settlement_amount.setter
    def settlement_amount(self, value):
        self._settlement_amount = value
    @property
    def settlement_ccy(self):
        return self._settlement_ccy

    @settlement_ccy.setter
    def settlement_ccy(self, value):
        self._settlement_ccy = value
    @property
    def side(self):
        return self._side

    @side.setter
    def side(self, value):
        self._side = value
    @property
    def slip_point(self):
        return self._slip_point

    @slip_point.setter
    def slip_point(self, value):
        self._slip_point = value
    @property
    def time_zone(self):
        return self._time_zone

    @time_zone.setter
    def time_zone(self, value):
        self._time_zone = value
    @property
    def tnt_inst_id(self):
        return self._tnt_inst_id

    @tnt_inst_id.setter
    def tnt_inst_id(self, value):
        self._tnt_inst_id = value
    @property
    def trade_timestamp(self):
        return self._trade_timestamp

    @trade_timestamp.setter
    def trade_timestamp(self, value):
        self._trade_timestamp = value
    @property
    def trade_type(self):
        return self._trade_type

    @trade_type.setter
    def trade_type(self, value):
        self._trade_type = value
    @property
    def transaction_amount(self):
        return self._transaction_amount

    @transaction_amount.setter
    def transaction_amount(self, value):
        self._transaction_amount = value
    @property
    def transaction_ccy(self):
        return self._transaction_ccy

    @transaction_ccy.setter
    def transaction_ccy(self, value):
        self._transaction_ccy = value
    @property
    def transaction_ccy_type(self):
        return self._transaction_ccy_type

    @transaction_ccy_type.setter
    def transaction_ccy_type(self, value):
        self._transaction_ccy_type = value
    @property
    def transaction_type(self):
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, value):
        self._transaction_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def value_date(self):
        return self._value_date

    @value_date.setter
    def value_date(self, value):
        self._value_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.acquirer:
            if hasattr(self.acquirer, 'to_alipay_dict'):
                params['acquirer'] = self.acquirer.to_alipay_dict()
            else:
                params['acquirer'] = self.acquirer
        if self.acquirer_mem_id:
            if hasattr(self.acquirer_mem_id, 'to_alipay_dict'):
                params['acquirer_mem_id'] = self.acquirer_mem_id.to_alipay_dict()
            else:
                params['acquirer_mem_id'] = self.acquirer_mem_id
        if self.aml_status:
            if hasattr(self.aml_status, 'to_alipay_dict'):
                params['aml_status'] = self.aml_status.to_alipay_dict()
            else:
                params['aml_status'] = self.aml_status
        if self.biz_ev_code:
            if hasattr(self.biz_ev_code, 'to_alipay_dict'):
                params['biz_ev_code'] = self.biz_ev_code.to_alipay_dict()
            else:
                params['biz_ev_code'] = self.biz_ev_code
        if self.biz_pd_code:
            if hasattr(self.biz_pd_code, 'to_alipay_dict'):
                params['biz_pd_code'] = self.biz_pd_code.to_alipay_dict()
            else:
                params['biz_pd_code'] = self.biz_pd_code
        if self.client_advice_timestamp:
            if hasattr(self.client_advice_timestamp, 'to_alipay_dict'):
                params['client_advice_timestamp'] = self.client_advice_timestamp.to_alipay_dict()
            else:
                params['client_advice_timestamp'] = self.client_advice_timestamp
        if self.client_business_id:
            if hasattr(self.client_business_id, 'to_alipay_dict'):
                params['client_business_id'] = self.client_business_id.to_alipay_dict()
            else:
                params['client_business_id'] = self.client_business_id
        if self.client_id:
            if hasattr(self.client_id, 'to_alipay_dict'):
                params['client_id'] = self.client_id.to_alipay_dict()
            else:
                params['client_id'] = self.client_id
        if self.client_message_id:
            if hasattr(self.client_message_id, 'to_alipay_dict'):
                params['client_message_id'] = self.client_message_id.to_alipay_dict()
            else:
                params['client_message_id'] = self.client_message_id
        if self.client_ref:
            if hasattr(self.client_ref, 'to_alipay_dict'):
                params['client_ref'] = self.client_ref.to_alipay_dict()
            else:
                params['client_ref'] = self.client_ref
        if self.client_system:
            if hasattr(self.client_system, 'to_alipay_dict'):
                params['client_system'] = self.client_system.to_alipay_dict()
            else:
                params['client_system'] = self.client_system
        if self.cnl_ev_code:
            if hasattr(self.cnl_ev_code, 'to_alipay_dict'):
                params['cnl_ev_code'] = self.cnl_ev_code.to_alipay_dict()
            else:
                params['cnl_ev_code'] = self.cnl_ev_code
        if self.cnl_no:
            if hasattr(self.cnl_no, 'to_alipay_dict'):
                params['cnl_no'] = self.cnl_no.to_alipay_dict()
            else:
                params['cnl_no'] = self.cnl_no
        if self.cnl_pd_code:
            if hasattr(self.cnl_pd_code, 'to_alipay_dict'):
                params['cnl_pd_code'] = self.cnl_pd_code.to_alipay_dict()
            else:
                params['cnl_pd_code'] = self.cnl_pd_code
        if self.contra_amount:
            if hasattr(self.contra_amount, 'to_alipay_dict'):
                params['contra_amount'] = self.contra_amount.to_alipay_dict()
            else:
                params['contra_amount'] = self.contra_amount
        if self.contra_ccy:
            if hasattr(self.contra_ccy, 'to_alipay_dict'):
                params['contra_ccy'] = self.contra_ccy.to_alipay_dict()
            else:
                params['contra_ccy'] = self.contra_ccy
        if self.extension:
            if hasattr(self.extension, 'to_alipay_dict'):
                params['extension'] = self.extension.to_alipay_dict()
            else:
                params['extension'] = self.extension
        if self.inst_entity:
            if hasattr(self.inst_entity, 'to_alipay_dict'):
                params['inst_entity'] = self.inst_entity.to_alipay_dict()
            else:
                params['inst_entity'] = self.inst_entity
        if self.is_locked:
            if hasattr(self.is_locked, 'to_alipay_dict'):
                params['is_locked'] = self.is_locked.to_alipay_dict()
            else:
                params['is_locked'] = self.is_locked
        if self.issuer:
            if hasattr(self.issuer, 'to_alipay_dict'):
                params['issuer'] = self.issuer.to_alipay_dict()
            else:
                params['issuer'] = self.issuer
        if self.issuer_mem_id:
            if hasattr(self.issuer_mem_id, 'to_alipay_dict'):
                params['issuer_mem_id'] = self.issuer_mem_id.to_alipay_dict()
            else:
                params['issuer_mem_id'] = self.issuer_mem_id
        if self.merchant_mcc:
            if hasattr(self.merchant_mcc, 'to_alipay_dict'):
                params['merchant_mcc'] = self.merchant_mcc.to_alipay_dict()
            else:
                params['merchant_mcc'] = self.merchant_mcc
        if self.msg_type:
            if hasattr(self.msg_type, 'to_alipay_dict'):
                params['msg_type'] = self.msg_type.to_alipay_dict()
            else:
                params['msg_type'] = self.msg_type
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        if self.partial_trade:
            if hasattr(self.partial_trade, 'to_alipay_dict'):
                params['partial_trade'] = self.partial_trade.to_alipay_dict()
            else:
                params['partial_trade'] = self.partial_trade
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.payment_provider:
            if hasattr(self.payment_provider, 'to_alipay_dict'):
                params['payment_provider'] = self.payment_provider.to_alipay_dict()
            else:
                params['payment_provider'] = self.payment_provider
        if self.payment_type:
            if hasattr(self.payment_type, 'to_alipay_dict'):
                params['payment_type'] = self.payment_type.to_alipay_dict()
            else:
                params['payment_type'] = self.payment_type
        if self.product_id:
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.profile_id:
            if hasattr(self.profile_id, 'to_alipay_dict'):
                params['profile_id'] = self.profile_id.to_alipay_dict()
            else:
                params['profile_id'] = self.profile_id
        if self.rate_base_ccy:
            if hasattr(self.rate_base_ccy, 'to_alipay_dict'):
                params['rate_base_ccy'] = self.rate_base_ccy.to_alipay_dict()
            else:
                params['rate_base_ccy'] = self.rate_base_ccy
        if self.rate_ref:
            if hasattr(self.rate_ref, 'to_alipay_dict'):
                params['rate_ref'] = self.rate_ref.to_alipay_dict()
            else:
                params['rate_ref'] = self.rate_ref
        if self.rate_request_mode:
            if hasattr(self.rate_request_mode, 'to_alipay_dict'):
                params['rate_request_mode'] = self.rate_request_mode.to_alipay_dict()
            else:
                params['rate_request_mode'] = self.rate_request_mode
        if self.rate_type:
            if hasattr(self.rate_type, 'to_alipay_dict'):
                params['rate_type'] = self.rate_type.to_alipay_dict()
            else:
                params['rate_type'] = self.rate_type
        if self.reference_field1:
            if hasattr(self.reference_field1, 'to_alipay_dict'):
                params['reference_field1'] = self.reference_field1.to_alipay_dict()
            else:
                params['reference_field1'] = self.reference_field1
        if self.reference_field2:
            if hasattr(self.reference_field2, 'to_alipay_dict'):
                params['reference_field2'] = self.reference_field2.to_alipay_dict()
            else:
                params['reference_field2'] = self.reference_field2
        if self.reference_field3:
            if hasattr(self.reference_field3, 'to_alipay_dict'):
                params['reference_field3'] = self.reference_field3.to_alipay_dict()
            else:
                params['reference_field3'] = self.reference_field3
        if self.related_message_id:
            if hasattr(self.related_message_id, 'to_alipay_dict'):
                params['related_message_id'] = self.related_message_id.to_alipay_dict()
            else:
                params['related_message_id'] = self.related_message_id
        if self.request_message_id:
            if hasattr(self.request_message_id, 'to_alipay_dict'):
                params['request_message_id'] = self.request_message_id.to_alipay_dict()
            else:
                params['request_message_id'] = self.request_message_id
        if self.requested_rate:
            if hasattr(self.requested_rate, 'to_alipay_dict'):
                params['requested_rate'] = self.requested_rate.to_alipay_dict()
            else:
                params['requested_rate'] = self.requested_rate
        if self.settlement_amount:
            if hasattr(self.settlement_amount, 'to_alipay_dict'):
                params['settlement_amount'] = self.settlement_amount.to_alipay_dict()
            else:
                params['settlement_amount'] = self.settlement_amount
        if self.settlement_ccy:
            if hasattr(self.settlement_ccy, 'to_alipay_dict'):
                params['settlement_ccy'] = self.settlement_ccy.to_alipay_dict()
            else:
                params['settlement_ccy'] = self.settlement_ccy
        if self.side:
            if hasattr(self.side, 'to_alipay_dict'):
                params['side'] = self.side.to_alipay_dict()
            else:
                params['side'] = self.side
        if self.slip_point:
            if hasattr(self.slip_point, 'to_alipay_dict'):
                params['slip_point'] = self.slip_point.to_alipay_dict()
            else:
                params['slip_point'] = self.slip_point
        if self.time_zone:
            if hasattr(self.time_zone, 'to_alipay_dict'):
                params['time_zone'] = self.time_zone.to_alipay_dict()
            else:
                params['time_zone'] = self.time_zone
        if self.tnt_inst_id:
            if hasattr(self.tnt_inst_id, 'to_alipay_dict'):
                params['tnt_inst_id'] = self.tnt_inst_id.to_alipay_dict()
            else:
                params['tnt_inst_id'] = self.tnt_inst_id
        if self.trade_timestamp:
            if hasattr(self.trade_timestamp, 'to_alipay_dict'):
                params['trade_timestamp'] = self.trade_timestamp.to_alipay_dict()
            else:
                params['trade_timestamp'] = self.trade_timestamp
        if self.trade_type:
            if hasattr(self.trade_type, 'to_alipay_dict'):
                params['trade_type'] = self.trade_type.to_alipay_dict()
            else:
                params['trade_type'] = self.trade_type
        if self.transaction_amount:
            if hasattr(self.transaction_amount, 'to_alipay_dict'):
                params['transaction_amount'] = self.transaction_amount.to_alipay_dict()
            else:
                params['transaction_amount'] = self.transaction_amount
        if self.transaction_ccy:
            if hasattr(self.transaction_ccy, 'to_alipay_dict'):
                params['transaction_ccy'] = self.transaction_ccy.to_alipay_dict()
            else:
                params['transaction_ccy'] = self.transaction_ccy
        if self.transaction_ccy_type:
            if hasattr(self.transaction_ccy_type, 'to_alipay_dict'):
                params['transaction_ccy_type'] = self.transaction_ccy_type.to_alipay_dict()
            else:
                params['transaction_ccy_type'] = self.transaction_ccy_type
        if self.transaction_type:
            if hasattr(self.transaction_type, 'to_alipay_dict'):
                params['transaction_type'] = self.transaction_type.to_alipay_dict()
            else:
                params['transaction_type'] = self.transaction_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.value_date:
            if hasattr(self.value_date, 'to_alipay_dict'):
                params['value_date'] = self.value_date.to_alipay_dict()
            else:
                params['value_date'] = self.value_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TradeRequestVO()
        if 'acquirer' in d:
            o.acquirer = d['acquirer']
        if 'acquirer_mem_id' in d:
            o.acquirer_mem_id = d['acquirer_mem_id']
        if 'aml_status' in d:
            o.aml_status = d['aml_status']
        if 'biz_ev_code' in d:
            o.biz_ev_code = d['biz_ev_code']
        if 'biz_pd_code' in d:
            o.biz_pd_code = d['biz_pd_code']
        if 'client_advice_timestamp' in d:
            o.client_advice_timestamp = d['client_advice_timestamp']
        if 'client_business_id' in d:
            o.client_business_id = d['client_business_id']
        if 'client_id' in d:
            o.client_id = d['client_id']
        if 'client_message_id' in d:
            o.client_message_id = d['client_message_id']
        if 'client_ref' in d:
            o.client_ref = d['client_ref']
        if 'client_system' in d:
            o.client_system = d['client_system']
        if 'cnl_ev_code' in d:
            o.cnl_ev_code = d['cnl_ev_code']
        if 'cnl_no' in d:
            o.cnl_no = d['cnl_no']
        if 'cnl_pd_code' in d:
            o.cnl_pd_code = d['cnl_pd_code']
        if 'contra_amount' in d:
            o.contra_amount = d['contra_amount']
        if 'contra_ccy' in d:
            o.contra_ccy = d['contra_ccy']
        if 'extension' in d:
            o.extension = d['extension']
        if 'inst_entity' in d:
            o.inst_entity = d['inst_entity']
        if 'is_locked' in d:
            o.is_locked = d['is_locked']
        if 'issuer' in d:
            o.issuer = d['issuer']
        if 'issuer_mem_id' in d:
            o.issuer_mem_id = d['issuer_mem_id']
        if 'merchant_mcc' in d:
            o.merchant_mcc = d['merchant_mcc']
        if 'msg_type' in d:
            o.msg_type = d['msg_type']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        if 'partial_trade' in d:
            o.partial_trade = d['partial_trade']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'payment_provider' in d:
            o.payment_provider = d['payment_provider']
        if 'payment_type' in d:
            o.payment_type = d['payment_type']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'profile_id' in d:
            o.profile_id = d['profile_id']
        if 'rate_base_ccy' in d:
            o.rate_base_ccy = d['rate_base_ccy']
        if 'rate_ref' in d:
            o.rate_ref = d['rate_ref']
        if 'rate_request_mode' in d:
            o.rate_request_mode = d['rate_request_mode']
        if 'rate_type' in d:
            o.rate_type = d['rate_type']
        if 'reference_field1' in d:
            o.reference_field1 = d['reference_field1']
        if 'reference_field2' in d:
            o.reference_field2 = d['reference_field2']
        if 'reference_field3' in d:
            o.reference_field3 = d['reference_field3']
        if 'related_message_id' in d:
            o.related_message_id = d['related_message_id']
        if 'request_message_id' in d:
            o.request_message_id = d['request_message_id']
        if 'requested_rate' in d:
            o.requested_rate = d['requested_rate']
        if 'settlement_amount' in d:
            o.settlement_amount = d['settlement_amount']
        if 'settlement_ccy' in d:
            o.settlement_ccy = d['settlement_ccy']
        if 'side' in d:
            o.side = d['side']
        if 'slip_point' in d:
            o.slip_point = d['slip_point']
        if 'time_zone' in d:
            o.time_zone = d['time_zone']
        if 'tnt_inst_id' in d:
            o.tnt_inst_id = d['tnt_inst_id']
        if 'trade_timestamp' in d:
            o.trade_timestamp = d['trade_timestamp']
        if 'trade_type' in d:
            o.trade_type = d['trade_type']
        if 'transaction_amount' in d:
            o.transaction_amount = d['transaction_amount']
        if 'transaction_ccy' in d:
            o.transaction_ccy = d['transaction_ccy']
        if 'transaction_ccy_type' in d:
            o.transaction_ccy_type = d['transaction_ccy_type']
        if 'transaction_type' in d:
            o.transaction_type = d['transaction_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'value_date' in d:
            o.value_date = d['value_date']
        return o


